@@ -5,6 +5,8 @@ tests.test_attrs
 Test Yaspin attributes magic hidden in __getattr__.
 """
 
+import sys
+
 import pytest
 
 from yaspin import yaspin
@@ -19,12 +21,13 @@ def test_set_spinner_by_name(attr_name):
 
 
 # Values for ``color`` argument
-def test_color(color_test_cases):
+def test_color(monkeypatch, color_test_cases):
     color, expected = color_test_cases
     # ``None`` and ``""`` are skipped
     if not color:
-        pytest.skip("{0} - unsupported case".format(repr(color)))
+        pytest.skip(f"{color!r} - unsupported case")
 
+    monkeypatch.setattr(sys.stdout, "isatty", lambda: True)
     sp = yaspin()
 
     if isinstance(expected, Exception):
@@ -37,12 +40,13 @@ def test_color(color_test_cases):
 
 
 # Values for ``on_color`` argument
-def test_on_color(on_color_test_cases):
+def test_on_color(monkeypatch, on_color_test_cases):
     on_color, expected = on_color_test_cases
     # ``None`` and ``""`` are skipped
     if not on_color:
-        pytest.skip("{0} - unsupported case".format(repr(on_color)))
+        pytest.skip(f"{on_color!r} - unsupported case")
 
+    monkeypatch.setattr(sys.stdout, "isatty", lambda: True)
     sp = yaspin()
 
     if isinstance(expected, Exception):
@@ -52,7 +56,7 @@ def test_on_color(on_color_test_cases):
         getattr(sp, on_color)
         assert sp.on_color == expected
         assert (
-            sp._color_func.keywords["on_color"] == expected
+            sp._color_func.keywords["on_color"] == expected  # pylint: disable=no-member
         )  # pylint: disable=no-member
 
 
@@ -60,7 +64,8 @@ def test_on_color(on_color_test_cases):
 @pytest.mark.parametrize(
     "attr", sorted([k for k, v in COLOR_MAP.items() if v == "attrs"])
 )
-def test_attrs(attr):
+def test_attrs(monkeypatch, attr):
+    monkeypatch.setattr(sys.stdout, "isatty", lambda: True)
     sp = yaspin()
     getattr(sp, attr)
     assert sp.attrs == [attr]
